developer

package
v0.0.0-...-9b06841 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 8, 2025 License: Apache-2.0 Imports: 12 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var ErrNotFound = sqlx.ErrNotFound

Functions

This section is empty.

Types

type Developer

type Developer struct {
	DataId          int64        `db:"data_id"`          // Generated Primary Key, Must Not Be Changed
	Id              int64        `db:"id"`               // Unique GitHub User ID
	Name            string       `db:"name"`             // Name
	Login           string       `db:"login"`            // Login
	AvatarUrl       string       `db:"avatar_url"`       // Profile Avatar URL
	Company         string       `db:"company"`          // Company
	Location        string       `db:"location"`         // Location
	Bio             string       `db:"bio"`              // User Biography
	Blog            string       `db:"blog"`             // Personal Blog URL
	Email           string       `db:"email"`            // Contact Email
	TwitterUsername string       `db:"twitter_username"` // Twitter Username
	Repos           int64        `db:"repos"`            // Repository Count
	Following       int64        `db:"following"`        // Following Count
	Followers       int64        `db:"followers"`        // Followers Count
	Stars           int64        `db:"stars"`            // Total Stars Received
	Gists           int64        `db:"gists"`            // Gists count
	CreatedAt       time.Time    `db:"created_at"`
	UpdatedAt       time.Time    `db:"updated_at"` // update data time
	DeletedAt       sql.NullTime `db:"deleted_at"`
}

type DeveloperModel

type DeveloperModel interface {
	FindOneByLogin(ctx context.Context, login string) (*Developer, error)
	CreateDataId() (int64, error)
	// contains filtered or unexported methods
}

DeveloperModel is an interface to be customized, add more methods here, and implement the added methods in customDeveloperModel.

func NewDeveloperModel

func NewDeveloperModel(conn sqlx.SqlConn, c cache.CacheConf, DatancenterId, WorkerId int64, opts ...cache.Option) DeveloperModel

NewDeveloperModel returns a model for the database table.

Jump to