relation

package
v0.0.0-...-9b06841 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 8, 2025 License: Apache-2.0 Imports: 12 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var ErrNotFound = sqlx.ErrNotFound

Functions

This section is empty.

Types

type CreateRepo

type CreateRepo struct {
	DataId      int64        `db:"data_id"`      // Generated Primary Key, Must Not Be Changed
	DeveloperId int64        `db:"developer_id"` // Unique GitHub User ID
	RepoId      int64        `db:"repo_id"`      // Unique GitHub Repository ID
	CreatedAt   time.Time    `db:"created_at"`
	UpdatedAt   time.Time    `db:"updated_at"` // update data time
	DeletedAt   sql.NullTime `db:"deleted_at"`
}

type CreateRepoModel

type CreateRepoModel interface {
	SearchCreatedRepo(ctx context.Context, developerId int64, page int64, limit int64) ([]*CreateRepo, error)
	CreateDataId() (int64, error)
	// contains filtered or unexported methods
}

CreateRepoModel is an interface to be customized, add more methods here, and implement the added methods in customCreateRepoModel.

func NewCreateRepoModel

func NewCreateRepoModel(conn sqlx.SqlConn, c cache.CacheConf, DatancenterId, WorkerId int64, opts ...cache.Option) CreateRepoModel

NewCreateRepoModel returns a model for the database table.

type CreatedRepoUpdatedAt

type CreatedRepoUpdatedAt struct {
	DataId      int64     `db:"data_id"`      // Generated Primary Key, Must Not Be Changed
	DeveloperId int64     `db:"developer_id"` // Unique GitHub User ID
	CreatedAt   time.Time `db:"created_at"`
	UpdatedAt   time.Time `db:"updated_at"` // update data time
}

type CreatedRepoUpdatedAtModel

type CreatedRepoUpdatedAtModel interface {
	CreateDataId() (int64, error)
	// contains filtered or unexported methods
}

CreatedRepoUpdatedAtModel is an interface to be customized, add more methods here, and implement the added methods in customCreatedRepoUpdatedAtModel.

func NewCreatedRepoUpdatedAtModel

func NewCreatedRepoUpdatedAtModel(conn sqlx.SqlConn, c cache.CacheConf, DatancenterId, WorkerId int64, opts ...cache.Option) CreatedRepoUpdatedAtModel

NewCreatedRepoUpdatedAtModel returns a model for the database table.

type Follow

type Follow struct {
	DataId      int64        `db:"data_id"`      // Generated Primary Key, Must Not Be Changed
	FollowerId  int64        `db:"follower_id"`  // Follower ID
	FollowingId int64        `db:"following_id"` // Following ID
	CreatedAt   time.Time    `db:"created_at"`
	UpdatedAt   time.Time    `db:"updated_at"` // update data time
	DeletedAt   sql.NullTime `db:"deleted_at"`
}

type FollowModel

type FollowModel interface {
	SearchFollowingByDeveloperId(ctx context.Context, developerId int64, page int64, limit int64) ([]*Follow, error)
	SearchFollowerByDeveloperId(ctx context.Context, developerId int64, page int64, limit int64) ([]*Follow, error)
	CreateDataId() (int64, error)
	// contains filtered or unexported methods
}

FollowModel is an interface to be customized, add more methods here, and implement the added methods in customFollowModel.

func NewFollowModel

func NewFollowModel(conn sqlx.SqlConn, c cache.CacheConf, DatancenterId, WorkerId int64, opts ...cache.Option) FollowModel

NewFollowModel returns a model for the database table.

type FollowerUpdatedAt

type FollowerUpdatedAt struct {
	DataId      int64     `db:"data_id"`      // Generated Primary Key, Must Not Be Changed
	DeveloperId int64     `db:"developer_id"` // Unique GitHub User ID
	CreatedAt   time.Time `db:"created_at"`
	UpdatedAt   time.Time `db:"updated_at"` // update data time
}

type FollowerUpdatedAtModel

type FollowerUpdatedAtModel interface {
	CreateDataId() (int64, error)
	// contains filtered or unexported methods
}

FollowerUpdatedAtModel is an interface to be customized, add more methods here, and implement the added methods in customFollowerUpdatedAtModel.

func NewFollowerUpdatedAtModel

func NewFollowerUpdatedAtModel(conn sqlx.SqlConn, c cache.CacheConf, DatancenterId, WorkerId int64, opts ...cache.Option) FollowerUpdatedAtModel

NewFollowerUpdatedAtModel returns a model for the database table.

type FollowingUpdatedAt

type FollowingUpdatedAt struct {
	DataId      int64     `db:"data_id"`      // Generated Primary Key, Must Not Be Changed
	DeveloperId int64     `db:"developer_id"` // Unique GitHub User ID
	CreatedAt   time.Time `db:"created_at"`
	UpdatedAt   time.Time `db:"updated_at"` // update data time
}

type FollowingUpdatedAtModel

type FollowingUpdatedAtModel interface {
	CreateDataId() (int64, error)
	// contains filtered or unexported methods
}

FollowingUpdatedAtModel is an interface to be customized, add more methods here, and implement the added methods in customFollowingUpdatedAtModel.

func NewFollowingUpdatedAtModel

func NewFollowingUpdatedAtModel(conn sqlx.SqlConn, c cache.CacheConf, DatancenterId, WorkerId int64, opts ...cache.Option) FollowingUpdatedAtModel

NewFollowingUpdatedAtModel returns a model for the database table.

type Star

type Star struct {
	DataId      int64        `db:"data_id"`      // Generated Primary Key, Must Not Be Changed
	DeveloperId int64        `db:"developer_id"` // Unique GitHub User ID
	RepoId      int64        `db:"repo_id"`      // Unique GitHub Repository ID
	CreatedAt   time.Time    `db:"created_at"`
	UpdatedAt   time.Time    `db:"updated_at"` // update data time
	DeletedAt   sql.NullTime `db:"deleted_at"`
}

type StarModel

type StarModel interface {
	SearchStarredRepo(ctx context.Context, developerId int64, page int64, limit int64) ([]*Star, error)
	SearchStaringDeveloper(ctx context.Context, repoId int64, page int64, limit int64) ([]*Star, error)
	CreateDataId() (int64, error)
	// contains filtered or unexported methods
}

StarModel is an interface to be customized, add more methods here, and implement the added methods in customStarModel.

func NewStarModel

func NewStarModel(conn sqlx.SqlConn, c cache.CacheConf, DatancenterId, WorkerId int64, opts ...cache.Option) StarModel

NewStarModel returns a model for the database table.

type StarredRepoUpdatedAt

type StarredRepoUpdatedAt struct {
	DataId      int64     `db:"data_id"`      // Generated Primary Key, Must Not Be Changed
	DeveloperId int64     `db:"developer_id"` // Unique GitHub User ID
	CreatedAt   time.Time `db:"created_at"`
	UpdatedAt   time.Time `db:"updated_at"` // update data time
}

type StarredRepoUpdatedAtModel

type StarredRepoUpdatedAtModel interface {
	CreateDataId() (int64, error)
	// contains filtered or unexported methods
}

StarredRepoUpdatedAtModel is an interface to be customized, add more methods here, and implement the added methods in customStarredRepoUpdatedAtModel.

func NewStarredRepoUpdatedAtModel

func NewStarredRepoUpdatedAtModel(conn sqlx.SqlConn, c cache.CacheConf, DatancenterId, WorkerId int64, opts ...cache.Option) StarredRepoUpdatedAtModel

NewStarredRepoUpdatedAtModel returns a model for the database table.

Jump to