Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ErrNotFound = sqlx.ErrNotFound
Functions ¶
This section is empty.
Types ¶
type CommentOfUserUpdatedAt ¶
type CommentOfUserUpdatedAtModel ¶
type CommentOfUserUpdatedAtModel interface {
CreateDataId() (int64, error)
// contains filtered or unexported methods
}
CommentOfUserUpdatedAtModel is an interface to be customized, add more methods here, and implement the added methods in customCommentOfUserUpdatedAtModel.
func NewCommentOfUserUpdatedAtModel ¶
func NewCommentOfUserUpdatedAtModel(conn sqlx.SqlConn, c cache.CacheConf, DatancenterId, WorkerId int64, opts ...cache.Option) CommentOfUserUpdatedAtModel
NewCommentOfUserUpdatedAtModel returns a model for the database table.
type Contribution ¶
type Contribution struct {
DataId int64 `db:"data_id"` // Generated Primary Key, Must Not Be Changed
ContributionId int64 `db:"contribution_id"` // Unique Contribution ID
DeveloperId int64 `db:"developer_id"` // Unique GitHub User ID
RepoId int64 `db:"repo_id"` // Unique GitHub Repository ID
Category string `db:"category"` // Category
Content string `db:"content"` // Contribution Content
ContributionCreatedAt time.Time `db:"contribution_created_at"` // Original creation timestamp
ContributionUpdatedAt time.Time `db:"contribution_updated_at"` // Last update timestamp
CreatedAt time.Time `db:"created_at"`
UpdatedAt time.Time `db:"updated_at"` // update data time
DeletedAt sql.NullTime `db:"deleted_at"`
}
type ContributionModel ¶
type ContributionModel interface {
SearchByCategory(ctx context.Context, category string, page int64, limit int64) ([]*Contribution, error)
SearchByDeveloperId(ctx context.Context, developerId int64, page int64, limit int64) ([]*Contribution, error)
SearchByRepoId(ctx context.Context, repoId int64, page int64, limit int64) ([]*Contribution, error)
CreateDataId() (int64, error)
// contains filtered or unexported methods
}
ContributionModel is an interface to be customized, add more methods here, and implement the added methods in customContributionModel.
func NewContributionModel ¶
func NewContributionModel(conn sqlx.SqlConn, c cache.CacheConf, DatancenterId, WorkerId int64, opts ...cache.Option) ContributionModel
NewContributionModel returns a model for the database table.
type IssuePrOfUserUpdatedAt ¶
type IssuePrOfUserUpdatedAtModel ¶
type IssuePrOfUserUpdatedAtModel interface {
CreateDataId() (int64, error)
// contains filtered or unexported methods
}
IssuePrOfUserUpdatedAtModel is an interface to be customized, add more methods here, and implement the added methods in customIssuePrOfUserUpdatedAtModel.
func NewIssuePrOfUserUpdatedAtModel ¶
func NewIssuePrOfUserUpdatedAtModel(conn sqlx.SqlConn, c cache.CacheConf, DatancenterId, WorkerId int64, opts ...cache.Option) IssuePrOfUserUpdatedAtModel
NewIssuePrOfUserUpdatedAtModel returns a model for the database table.
type ReviewOfUserUpdatedAt ¶
type ReviewOfUserUpdatedAtModel ¶
type ReviewOfUserUpdatedAtModel interface {
CreateDataId() (int64, error)
// contains filtered or unexported methods
}
ReviewOfUserUpdatedAtModel is an interface to be customized, add more methods here, and implement the added methods in customReviewOfUserUpdatedAtModel.
func NewReviewOfUserUpdatedAtModel ¶
func NewReviewOfUserUpdatedAtModel(conn sqlx.SqlConn, c cache.CacheConf, DatancenterId, WorkerId int64, opts ...cache.Option) ReviewOfUserUpdatedAtModel
NewReviewOfUserUpdatedAtModel returns a model for the database table.